@@ -5,7 +5,7 @@ except ImportError:
     import re
 
 
-PLACEHOLDER = '<@!hmin_placeholder_%s_lol_!@>'
+PLACEHOLDER = '<@!hmin_placeholder_%s_!@>'
 RE_REPLACED_TAG = re.compile(
     ur'(<(script|textarea|style|pre).*?>.*?</(script|textarea|style|pre)>)', re.S
 )
@@ -19,9 +19,6 @@ def minify(content, remove_comments=True):
         safe_storage[key] = m.group(1)
         return key
 
-    def tag_return(m):
-        return safe_storage[int(m.group(1))]
-
     # decode unicode
     try:
         content = content.decode('utf-8')
@@ -41,8 +38,6 @@ def minify(content, remove_comments=True):
 
     # and return dangerous tags back
     for key, value in safe_storage.items():
-        content.replace(key, value)
+        content = content.replace(key, value)
 
     return content
-    #return content
-    # return RE_PLACEHOLDER.sub(tag_return, content).strip()
